/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.dao.impl;

import dk.sds.ecpr2.domain.ExportHistoryVO;
import org.springframework.jdbc.core.RowMapper;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;

public class ExportHistoryRowMapper implements RowMapper<ExportHistoryVO> {

    @Override
    public ExportHistoryVO mapRow(ResultSet resultSet, int i) throws SQLException {
        final ExportHistoryVO exportHistoryVO = new ExportHistoryVO();

        exportHistoryVO.setExportId(resultSet.getInt("ExportId"));
        exportHistoryVO.setExportNumber(resultSet.getInt("ExportNumber"));
        exportHistoryVO.setExportTime(getTimestampFromResultset(resultSet, "ExportTime"));
        exportHistoryVO.setErrorMessage(resultSet.getString("ErrorMessage"));
        return exportHistoryVO;
    }

    public Date getTimestampFromResultset(ResultSet resultSet, String field) throws SQLException {
        Date tmpResult = resultSet.getTimestamp(field);
        if (tmpResult == null) {
            return null;
        }
        return new Date(tmpResult.getTime());
    }
}
