/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import dk.sds.ecpr2.constants.SearchConstants;
import dk.sds.ecpr2.domain.abstr.PersonDescriptorWithServiceActorVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
public class AddressVO extends PersonDescriptorWithServiceActorVO {

    @JsonIgnore
    private Integer addressPID;
    private String type;
    private String use;
    private String streetAddressLine1;
    private String streetAddressLine2;
    private String streetAddressLine3;
    private String streetAddressLine4;
    private String streetAddressLine5;
    private String streetAddressLine6;
    private String streetAddressLine7;
    private String streetAddressLine8;
    private String streetAddressLine9;
    private String streetAddressLine10;
    private String city;
    private String district;
    private String state;
    private String postalCode;
    private String country;
    private String postBox;
    private Date expiry;
    private String personUUID;

    @JsonIgnore
    public List<LuceneKeyValue> getLuceneList() {
        List<LuceneKeyValue> luceneKeyValueList = new ArrayList<>();

        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine1));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine2));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine3));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine4));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine5));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine6));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine7));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine8));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine9));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STREET_ADDRESS, streetAddressLine10));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.CITY, city));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.DISTRICT, district));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.STATE, state));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.POSTAL_CODE, postalCode));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.COUNTRY, country));
        return luceneKeyValueList;
    }

    public Integer getAddressPID() { return addressPID; }
    public void setAddressPID(Integer addressPID) { this.addressPID = addressPID; }

    public String getType() { return type; }
    public void setType(String type) { this.type = type; }

    public String getUse() { return use; }
    public void setUse(String use) { this.use = use; }

    public String getStreetAddressLine1() { return streetAddressLine1; }
    public void setStreetAddressLine1(String streetAddressLine1) { this.streetAddressLine1 = streetAddressLine1; }

    public String getStreetAddressLine2() { return streetAddressLine2; }
    public void setStreetAddressLine2(String streetAddressLine2) { this.streetAddressLine2 = streetAddressLine2; }

    public String getStreetAddressLine3() { return streetAddressLine3; }
    public void setStreetAddressLine3(String streetAddressLine3) { this.streetAddressLine3 = streetAddressLine3; }

    public String getStreetAddressLine4() { return streetAddressLine4; }
    public void setStreetAddressLine4(String streetAddressLine4) { this.streetAddressLine4 = streetAddressLine4; }

    public String getStreetAddressLine5() { return streetAddressLine5; }
    public void setStreetAddressLine5(String streetAddressLine5) { this.streetAddressLine5 = streetAddressLine5; }

    public String getStreetAddressLine6() { return streetAddressLine6; }
    public void setStreetAddressLine6(String streetAddressLine6) { this.streetAddressLine6 = streetAddressLine6; }

    public String getStreetAddressLine7() { return streetAddressLine7; }
    public void setStreetAddressLine7(String streetAddressLine7) { this.streetAddressLine7 = streetAddressLine7; }

    public String getStreetAddressLine8() { return streetAddressLine8; }
    public void setStreetAddressLine8(String streetAddressLine8) { this.streetAddressLine8 = streetAddressLine8; }

    public String getStreetAddressLine9() { return streetAddressLine9; }
    public void setStreetAddressLine9(String streetAddressLine9) { this.streetAddressLine9 = streetAddressLine9; }

    public String getStreetAddressLine10() { return streetAddressLine10; }
    public void setStreetAddressLine10(String streetAddressLine10) { this.streetAddressLine10 = streetAddressLine10; }

    public String getCity() { return city; }
    public void setCity(String city) { this.city = city; }

    public String getDistrict() { return district; }
    public void setDistrict(String district) { this.district = district; }

    public String getState() { return state; }
    public void setState(String state) { this.state = state; }

    public String getPostalCode() { return postalCode; }
    public void setPostalCode(String postalCode) { this.postalCode = postalCode; }

    public String getCountry() { return country; }
    public void setCountry(String country) { this.country = country; }

    public String getPostBox() { return postBox; }
    public void setPostBox(String postBox) { this.postBox = postBox; }

    public Date getExpiry() { return expiry; }
    public void setExpiry(Date expiry) { this.expiry = expiry; }

    public String getPersonUUID() { return personUUID; }
    public void setPersonUUID(String personUUID) { this.personUUID = personUUID; }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        //if (!super.equals(o)) return false;
        AddressVO addressVO = (AddressVO) o;
        return Objects.equals(getType(), addressVO.getType()) && Objects.equals(getUse(), addressVO.getUse()) && Objects.equals(getStreetAddressLine1(), addressVO.getStreetAddressLine1()) && Objects.equals(getStreetAddressLine2(), addressVO.getStreetAddressLine2()) && Objects.equals(getStreetAddressLine3(), addressVO.getStreetAddressLine3()) && Objects.equals(getStreetAddressLine4(), addressVO.getStreetAddressLine4()) && Objects.equals(getStreetAddressLine5(), addressVO.getStreetAddressLine5()) && Objects.equals(getStreetAddressLine6(), addressVO.getStreetAddressLine6()) && Objects.equals(getStreetAddressLine7(), addressVO.getStreetAddressLine7()) && Objects.equals(getStreetAddressLine8(), addressVO.getStreetAddressLine8()) && Objects.equals(getStreetAddressLine9(), addressVO.getStreetAddressLine9()) && Objects.equals(getStreetAddressLine10(), addressVO.getStreetAddressLine10()) && Objects.equals(getCity(), addressVO.getCity()) && Objects.equals(getDistrict(), addressVO.getDistrict()) && Objects.equals(getState(), addressVO.getState()) && Objects.equals(getPostalCode(), addressVO.getPostalCode()) && Objects.equals(getCountry(), addressVO.getCountry()) && Objects.equals(getPostBox(), addressVO.getPostBox()) && Objects.equals(getExpiry(), addressVO.getExpiry());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getType(), getUse(), getStreetAddressLine1(), getStreetAddressLine2(), getStreetAddressLine3(), getStreetAddressLine4(), getStreetAddressLine5(), getStreetAddressLine6(), getStreetAddressLine7(), getStreetAddressLine8(), getStreetAddressLine9(), getStreetAddressLine10(), getCity(), getDistrict(), getState(), getPostalCode(), getCountry(), getPostBox(), getExpiry());
    }

}
