/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import dk.sds.ecpr2.constants.SearchConstants;
import dk.sds.ecpr2.domain.abstr.PersonDescriptorWithServiceActorVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;


@JsonInclude(JsonInclude.Include.NON_NULL)
public class ContactVO extends PersonDescriptorWithServiceActorVO {
    @JsonIgnore
    private Integer contactPID;
    private String system;
    private String use;
    private String value;
    private Date expiry;
    private String personUUID;

    @JsonIgnore
    public List<LuceneKeyValue> getLuceneList() {
        List<LuceneKeyValue> luceneKeyValueList = new ArrayList<>();
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.CONTACT, value));
        luceneKeyValueList.add(new LuceneKeyValue(SearchConstants.CONTACT_SYSTEM, system));

        return luceneKeyValueList;
    }

    public Integer getContactPID() {
        return contactPID;
    }

    public void setContactPID(Integer contactPID) {
        this.contactPID = contactPID;
    }

    public String getSystem() {
        return system;
    }

    public void setSystem(String system) {
        this.system = system;
    }

    public String getUse() {
        return use;
    }

    public void setUse(String use) {
        this.use = use;
    }

    public String getValue() {
        return value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public Date getExpiry() {
        return expiry;
    }

    public void setExpiry(Date expiry) {
        this.expiry = expiry;
    }

    public String getPersonUUID() {
        return personUUID;
    }

    public void setPersonUUID(String personUUID) {
        this.personUUID = personUUID;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContactVO contactVO = (ContactVO) o;
        return Objects.equals(system, contactVO.system) && Objects.equals(use, contactVO.use) && Objects.equals(value, contactVO.value) && Objects.equals(expiry, contactVO.expiry);
    }

    @Override
    public int hashCode() {
        return Objects.hash(system, use, value, expiry);
    }
}
