/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.util;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;

import java.util.Objects;

@Configuration
@PropertySource(value = "ecpr2.properties", encoding = "ISO-8859-1")
public class Properties {

    @Value("${dcc.endpoint}")
    public String dccEndpoint;

    @Value("${schemavalidation.validate.requests:true}")
    public boolean schemavalidationValidateRequests;

    @Value("${schemavalidation.validate.responses:true}")
    public boolean schemavalidationValidateResponse;

    @Value("${schemavalidation.fail.on.response.error:true}")
    public boolean schemavalidationFailOnResponseError;

    @Value("${max.reserved.personid.number:100}")
    public int maxReservedPersonIdNumber;

    @Value("${max.reserved.personid.number.pr.day:100}")
    public int maxReservedPersonIdNumberPrDay;

    @Value("${advis.enabled:true}")
    public boolean advisEnabled;

    @Value("${stamdata.cpr.url}")
    public String cprUrl;

    @Value("${isProduction:true}")
    public boolean isProduction;

    public String getDccEndpoint() {
        return dccEndpoint;
    }

    public void setDccEndpoint(String dccEndpoint) {
        this.dccEndpoint = dccEndpoint;
    }

    public boolean isSchemavalidationValidateRequests() {
        return schemavalidationValidateRequests;
    }

    public void setSchemavalidationValidateRequests(boolean schemavalidationValidateRequests) {
        this.schemavalidationValidateRequests = schemavalidationValidateRequests;
    }

    public boolean isSchemavalidationValidateResponse() {
        return schemavalidationValidateResponse;
    }

    public void setSchemavalidationValidateResponse(boolean schemavalidationValidateResponse) {
        this.schemavalidationValidateResponse = schemavalidationValidateResponse;
    }

    public boolean isSchemavalidationFailOnResponseError() {
        return schemavalidationFailOnResponseError;
    }

    public void setSchemavalidationFailOnResponseError(boolean schemavalidationFailOnResponseError) {
        this.schemavalidationFailOnResponseError = schemavalidationFailOnResponseError;
    }

    public int getMaxReservedPersonIdNumber() {
        return maxReservedPersonIdNumber;
    }

    public void setMaxReservedPersonIdNumber(int maxReservedPersonIdNumber) {
        this.maxReservedPersonIdNumber = maxReservedPersonIdNumber;
    }

    public int getMaxReservedPersonIdNumberPrDay() {
        return maxReservedPersonIdNumberPrDay;
    }

    public void setMaxReservedPersonIdNumberPrDay(int maxReservedPersonIdNumberPrDay) {
        this.maxReservedPersonIdNumberPrDay = maxReservedPersonIdNumberPrDay;
    }

    public boolean isAdvisEnabled() {
        return advisEnabled;
    }

    public void setAdvisEnabled(boolean advisEnabled) {
        this.advisEnabled = advisEnabled;
    }

    public String getCprUrl() {
        return cprUrl;
    }

    public void setCprUrl(String cprUrl) {
        this.cprUrl = cprUrl;
    }

    public boolean isProduction() {
        return isProduction;
    }

    public void setProduction(boolean production) {
        isProduction = production;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Properties)) return false;
        Properties that = (Properties) o;
        return schemavalidationValidateRequests == that.schemavalidationValidateRequests && schemavalidationValidateResponse == that.schemavalidationValidateResponse && schemavalidationFailOnResponseError == that.schemavalidationFailOnResponseError && maxReservedPersonIdNumber == that.maxReservedPersonIdNumber && maxReservedPersonIdNumberPrDay == that.maxReservedPersonIdNumberPrDay && advisEnabled == that.advisEnabled && isProduction == that.isProduction && Objects.equals(dccEndpoint, that.dccEndpoint) && Objects.equals(cprUrl, that.cprUrl);
    }

    @Override
    public int hashCode() {
        return Objects.hash(dccEndpoint, schemavalidationValidateRequests, schemavalidationValidateResponse, schemavalidationFailOnResponseError, maxReservedPersonIdNumber, maxReservedPersonIdNumberPrDay, advisEnabled, cprUrl, isProduction);
    }
}
