/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.advis;

import dk.sds.ecpr2.domain.RequestContextVO;
import dk.sds.ecpr2.util.Properties;
import dk.sds.ecpr2.util.SosiUtil;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.xml.sax.SAXException;

import javax.xml.parsers.ParserConfigurationException;
import java.io.IOException;

@Component
public class AdvisFacadeImpl implements AdvisFacade {

	@Autowired
	Properties properties;

	@Autowired SosiUtil sosiUtil;

	@Value("${nas.url}") String baseUrl;

	private static final Logger log = LogManager.getLogger(AdvisFacadeImpl.class);

	@Override
	public void advisPersonIdUpdated(RequestContextVO context, String oid, String id) {
		if (!properties.advisEnabled) {
			log.warn("Advis forwarding is disabled - skipping");
			return;
		}
		// Generer XML
		String payload = AdvisXmlGenerator.createPayload("Updated");
		String request = AdvisXmlGenerator.packInNotify(payload, "http://sds.dk/personid/2018/01/01", oid + ":" + id, "http://sds.dk/personid/advis/OIDID");
		// Send XML
		try {
			String response = sosiUtil.sendServiceRequestStr(baseUrl + "/nas2/notificationbroker", "http://docs.oasis-open.org/wsn/bw-2/NotificationConsumer/Notify", request);
		} catch (ParserConfigurationException|SAXException e) {
			log.error("Unable to parse xml.", e);
			log.error("Xml: " + request);
			return;
		} catch (IOException e) {
			log.error("Error sending advis.", e);
			throw new RuntimeException(e);
		}
		log.debug("Sent updated advis for: " + oid + ":" + id);
	}

	@Override
	public void advisPersonIdDeleted(RequestContextVO context, String oid, String id) {
		if (!properties.advisEnabled) {
			log.warn("Advis forwarding is disabled - skipping");
			return;
		}
		// Generer XML
		String payload = AdvisXmlGenerator.createPayload("Deleted");
		String request = AdvisXmlGenerator.packInNotify(payload, "http://sds.dk/personid/2018/01/01", oid + ":" + id, "http://sds.dk/personid/advis/OIDID");
		// Send XML
		try {
			String response = sosiUtil.sendServiceRequestStr(baseUrl + "/nas2/notificationbroker", "http://docs.oasis-open.org/wsn/bw-2/NotificationConsumer/Notify", request);
		} catch (ParserConfigurationException|SAXException e) {
			log.error("Unable to parse xml.", e);
			log.error("Xml: " + request);
			return;
		} catch (IOException e) {
			log.error("Error sending advis.", e);
			throw new RuntimeException(e);
		}
		log.debug("Sent deleted advis for: " + oid + ":" + id);
	}
}
