/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.domain;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Date;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
public class OIDVO {
    @JsonIgnore
    private Integer oidPID;
    private String oid;
    @JsonProperty("oidLabel")
    private String primaryOidLabel;
    @JsonIgnore
    private String secondaryOidLabel;
    private String regex;
    private String type;
    private Date modifiedTime;

    @JsonIgnore
    public boolean isCountryBased() {
        return oid.startsWith("1.2.208.176.1.6.3");
    }

    public Integer getOidPID() {
        return oidPID;
    }

    public void setOidPID(Integer oidPID) {
        this.oidPID = oidPID;
    }

    public String getOid() {
        return oid;
    }

    public void setOid(String oid) {
        this.oid = oid;
    }

    public String getPrimaryOidLabel() {
        return primaryOidLabel;
    }

    public void setPrimaryOidLabel(String primaryOidLabel) {
        this.primaryOidLabel = primaryOidLabel;
    }

    public String getSecondaryOidLabel() {
        return secondaryOidLabel;
    }

    public void setSecondaryOidLabel(String secondaryOidLabel) {
        this.secondaryOidLabel = secondaryOidLabel;
    }

    public String getRegex() {
        return regex;
    }

    public void setRegex(String regex) {
        this.regex = regex;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getModifiedTime() {
        return modifiedTime;
    }

    public void setModifiedTime(Date modifiedTime) {
        this.modifiedTime = modifiedTime;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        OIDVO oidvo = (OIDVO) o;
        return Objects.equals(oidPID, oidvo.oidPID) && Objects.equals(oid, oidvo.oid) && Objects.equals(primaryOidLabel, oidvo.primaryOidLabel) && Objects.equals(secondaryOidLabel, oidvo.secondaryOidLabel) && Objects.equals(regex, oidvo.regex) && Objects.equals(type, oidvo.type) && Objects.equals(modifiedTime, oidvo.modifiedTime);
    }

    @Override
    public int hashCode() {
        return Objects.hash(oidPID, oid, primaryOidLabel, secondaryOidLabel, regex, type, modifiedTime);
    }
}
