/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.util;

import dk.sdsd.nsp.slalog.api.SLALogConfig;
import dk.sdsd.nsp.slalog.api.SLALogItem;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;

public class SlaLogger {
    private static final Logger log = LogManager.getLogger(SlaLogger.class);

    private static final String SHORT_APP_NAME = "ecpr2";
    private static final Integer lock = 1;
    private static SLALogConfig slaLogInstance;

    private String name;

    public SlaLogger(String name) {
        this.name = name;
        synchronized (lock) {
            if (slaLogInstance == null) {
                slaLogInstance = new SLALogConfig(SHORT_APP_NAME, SHORT_APP_NAME);
            }
        }
    }

    public void addSlaLog(SLALogItem slaLogItem, long startNanos, long startMillis, String errorMessage) {
        if (slaLogInstance == null) {
            log.error("No slaLogInstance has been created");
            return;
        }
        if (slaLogItem == null) {
            log.error("No slaLogItem was supplied");
            return;
        }
        try {
            SLALogItem logItem = slaLogInstance.getSLALogger().createLogItem(SHORT_APP_NAME + "." + name, SHORT_APP_NAME + "." + name);

            logItem.setClientIP(slaLogItem.getClientIP());
            logItem.setSourceSOAPAction(slaLogItem.getSourceSOAPAction());
            logItem.setSourceOperation(slaLogItem.getSourceOperation());
            logItem.setSourceEndpoint(slaLogItem.getSourceEndpoint());
            logItem.setMessageId(slaLogItem.getMessageId());
            logItem.setStartTime(startNanos, startMillis);
            logItem.setEndTime(System.nanoTime(), System.currentTimeMillis());

            if (errorMessage == null) {
                logItem.setCallResultOk();
            } else {
                logItem.setCallResultError(errorMessage);
            }

            logItem.store();
        } catch (Exception ex) {
            log.error("Could not create SLA LogItem", ex);
        }
    }
}

