/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.webservice;

import dk.sds.ecpr2.security.RequestContext;
import dk.sds.ecpr2.util.ECPRException;
import dk.sds.ecpr2.util.FaultCode;
import dk.sds.ecpr2.util.FaultUtil;
import dk.sds.ecpr2.webservice.exceptions.ParseException;
import org.apache.log4j.LogManager;
import org.apache.log4j.Logger;
import dk.sdsd.nsp.slalog.api.SLALogItem;
import dk.sdsd.nsp.slalog.ws.SLALoggingServletFilter;
import org.springframework.context.annotation.AnnotationConfigApplicationContext;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.servlet.ServletContext;
import javax.servlet.ServletRequest;
import javax.xml.ws.WebServiceContext;
import javax.xml.ws.handler.MessageContext;

public class AbstractWebService {
    private static final Logger log = LogManager.getLogger(AbstractWebService.class);

    @Resource
    protected WebServiceContext context;

    @PostConstruct
    public void init() {
        if (context == null) {
            return;
        }
        ServletContext servletContext = (ServletContext) context.getMessageContext().get(MessageContext.SERVLET_CONTEXT);
        Object o = servletContext.getAttribute("ANNOTATION_CONFIG_APPLICATION_CONTEXT");
        ((AnnotationConfigApplicationContext) o).getAutowireCapableBeanFactory().autowireBean(this);
    }

    public void setupSlalogItem() {
        if (context == null) {
            return;
        }
        ServletRequest servletRequest = (ServletRequest) context.getMessageContext().get(MessageContext.SERVLET_REQUEST);
        SLALogItem slaLogItem = (SLALogItem) servletRequest.getAttribute(SLALoggingServletFilter.CURRENT_LOGITEM_REQUEST_KEY);
        if (slaLogItem == null) {
            log.error("No SLALogItem generated");
        }
        RequestContext.get().setSLALogItem(slaLogItem);
    }

    protected void commonExceptionHandler(Exception e, FaultCode validationErrorCode, FaultCode internalServerErrorCode) {
        log.warn(e);
        e.printStackTrace();
        if (e instanceof IllegalArgumentException || e instanceof ParseException) {
            FaultUtil.throwFault(validationErrorCode, e.getMessage(), e);
        } else if (e instanceof ECPRException) {
            final ECPRException ecprEx = (ECPRException) e;
            FaultUtil.throwFault(ecprEx.getFaultCode(), ecprEx.getMessage(), ecprEx);
        }

        FaultUtil.throwFault(internalServerErrorCode, e);
    }
}
